@@ -65,27 +65,38 @@ def get_image_captioning_models():
     # Check if models directory exists
     if not os.path.exists(models_dir):
         os.makedirs(models_dir)
+    print("=> Downloading models...")
 
     # Check if models exist in the models directory
-    model_path = os.path.join(models_dir, "pytorch_model.bin")
-    feature_extractor_path = os.path.join(models_dir, "processor.pt")
-    tokenizer_path = os.path.join(models_dir, "tokenizer")
+    # model_path = os.path.join(models_dir, "pytorch_model.bin")
+    # feature_extractor_path = os.path.join(models_dir, "processor.pt")
+    # tokenizer_path = os.path.join(models_dir, "tokenizer")
 
-    if os.path.exists(model_path) and os.path.exists(feature_extractor_path) and os.path.exists(tokenizer_path):
-        # Load the models if they exist
-        model = VisionEncoderDecoderModel.from_pretrained(models_dir)
-        feature_extractor = ViTImageProcessor.from_pretrained(models_dir)
-        tokenizer = AutoTokenizer.from_pretrained(models_dir)
-    else:
-        # Download and save the models if they don't exist
-        print("=> Downloading models...")
-        model = VisionEncoderDecoderModel.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
-        feature_extractor = ViTImageProcessor.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
-        tokenizer = AutoTokenizer.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    model = VisionEncoderDecoderModel.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    feature_extractor = ViTImageProcessor.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    tokenizer = AutoTokenizer.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
 
-        model.save_pretrained(models_dir)
-        feature_extractor.save_pretrained(models_dir)
-        tokenizer.save_pretrained(models_dir)
-        print("=> Downloading models - Done!")
+    # if os.path.exists(model_path) and os.path.exists(feature_extractor_path) and os.path.exists(tokenizer_path):
+    #     print("=> Downloading models...")
 
+    # model = VisionEncoderDecoderModel.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    # feature_extractor = ViTImageProcessor.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    # tokenizer = AutoTokenizer.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+
+    #
+    #     # Load the models if they exist
+    #     model = VisionEncoderDecoderModel.from_pretrained(models_dir)
+    #     feature_extractor = ViTImageProcessor.from_pretrained(models_dir)
+    #     tokenizer = AutoTokenizer.from_pretrained(models_dir)
+    # else:
+    #     # Download and save the models if they don't exist
+    #     print("=> Downloading models...")
+    #     model = VisionEncoderDecoderModel.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    #     feature_extractor = ViTImageProcessor.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    #     tokenizer = AutoTokenizer.from_pretrained("nlpconnect/vit-gpt2-image-captioning")
+    #
+    #     model.save_pretrained(models_dir)
+    #     feature_extractor.save_pretrained(models_dir)
+    #     tokenizer.save_pretrained(models_dir)
+    print("=> Downloading models - Done!")
     return model, feature_extractor, tokenizer
