@@ -52,7 +52,7 @@ diamond_collector = run(images=X[0:100],
                         image_shape=image_shape,
                         labels=y[0:100],
                         get_image_description=True,
-                        is_augment_data=False,
+                        is_augment_data=True,
                         image_augmentation_info=ImagesAugmentationInfo(aug_prop=0.2),
                         is_train_model=False, image_models=image_models,
                         is_post_model_analysis=False,
