@@ -1,16 +1,12 @@
 import pickle
 
 import numpy as np
-import os
-
-import numpy as np
-import pandas as pd
-# exec(open("/Users/amitosi/PycharmProjects/chester/diamond/manual_run.py").read())
-from PIL import Image
 
 from diamond.run import run
 from diamond.user_classes import ImagesAugmentationInfo, ImageModel, ImageModels
 
+# exec(open("/Users/amitosi/PycharmProjects/chester/diamond/manual_run.py").read())
+
 # define directory path
 with open("/Users/amitosi/PycharmProjects/chester/chester/data/data_batch_1", 'rb') as fo:
     data = pickle.load(fo, encoding='bytes')
@@ -28,7 +24,6 @@ labels = np.array(data[b'labels'][0:20])
 
 image_shape = (3, 32, 32)
 
-
 image_model_list = [
     ImageModel(network_name="EfficientNetB0",
                batch_size=64 * 64 * 16,
