@@ -9,13 +9,14 @@ import pandas as pd
 
 
 class ImagesData:
-    def __init__(self, images, labels, validation_prop, image_shape, label_dict):
+    def __init__(self, images, labels, validation_prop, image_shape, label_dict, for_model_training=True):
         self.images = images
         self.raw_images = self.images
         self.labels = labels
         self.validation_prop = validation_prop
         self.image_shape = image_shape
         self.label_dict = label_dict
+        self.for_model_training = for_model_training
         self.validate()
         self.problem_type = self.get_problem_type()
         # reshape
@@ -27,7 +28,8 @@ class ImagesData:
         self.is_colored = True if len(self.image_shape) > 2 else False
         self.images_to_show = None
         self.image_to_show()
-        self.images_train, self.labels_train, self.images_val, self.labels_val = self.split()
+        if self.for_model_training:
+            self.images_train, self.labels_train, self.images_val, self.labels_val = self.split()
         if self.is_colored:
             print("Colored image")
         else:
@@ -36,7 +38,7 @@ class ImagesData:
     def validate(self):
         if self.labels is None:
             pass
-        assert (len(self.images) == len(self.labels), "# of Images must be == # of labels")
+        assert len(self.images) == len(self.labels), "# of Images must be == # of labels"
 
     def image_to_show(self):
         images = self.images.reshape((-1,) + self.image_shape)
